@@ -74,9 +74,12 @@ type Pager struct {
 	isShowingHelp bool
 	preHelpState  *_PreHelpState
 
-	// NewPager shows lines by default, this field can hide them
+	// User preference
 	ShowLineNumbers bool
 
+	// Current state, initialized in StartPaging()
+	showLineNumbers bool
+
 	StatusBarStyle StatusBarOption
 	ShowStatusBar  bool
 
@@ -88,8 +91,8 @@ type Pager struct {
 	QuitIfOneScreen bool
 
 	// Ref: https://github.com/walles/moor/issues/94
-	ScrollLeftHint  twin.StyledRune
-	ScrollRightHint twin.StyledRune
+	ScrollLeftHint  textstyles.CellWithMetadata
+	ScrollRightHint textstyles.CellWithMetadata
 
 	SideScrollAmount int // Left / right arrow keys scroll amount
 
@@ -138,6 +141,7 @@ Miscellaneous
 * Press 'w' to toggle wrapping of long lines
 * Press '=' to toggle showing the status bar at the bottom
 * Press 'v' to edit the file in your favorite editor
+* Press CTRL-t to change the tab size
 
 Moving around
 -------------
@@ -155,6 +159,7 @@ Moving around
 * < / 'gg' to go to the start of the document
 * > / 'G' to go to the end of the document
 * Half page 'u'p / 'd'own, or CTRL-u / CTRL-d
+* CTRL-a moves to the leftmost position
 * RETURN moves down one line
 
 Switching files (if you opened multiple files)
@@ -212,13 +217,14 @@ func NewPager(readers ...*reader.ReaderImpl) *Pager {
 		currentReader:    0,
 		readerSwitched:   make(chan struct{}, 1),
 		quit:             false,
-		ShowLineNumbers:  true,
+		ShowLineNumbers:  true, // Constant throghout the lifetime of the pager
+		showLineNumbers:  true, // Will be updated over time
 		ShowStatusBar:    true,
 		DeInit:           true,
 		SideScrollAmount: 16,
 		TabSize:          8, // This is what less defaults to
-		ScrollLeftHint:   twin.NewStyledRune('<', twin.StyleDefault.WithAttr(twin.AttrReverse)),
-		ScrollRightHint:  twin.NewStyledRune('>', twin.StyleDefault.WithAttr(twin.AttrReverse)),
+		ScrollLeftHint:   textstyles.CellWithMetadata{Rune: '<', Style: twin.StyleDefault.WithAttr(twin.AttrReverse)},
+		ScrollRightHint:  textstyles.CellWithMetadata{Rune: '>', Style: twin.StyleDefault.WithAttr(twin.AttrReverse)},
 		scrollPosition:   newScrollPosition(name),
 	}
 
@@ -235,17 +241,22 @@ func NewPager(readers ...*reader.ReaderImpl) *Pager {
 // not the status bar is visible.
 func (p *Pager) visibleHeight() int {
 	_, height := p.screen.Size()
-	if p.ShowStatusBar {
+
+	// Only the viewing mode can be without status bar
+	hasStatusBar := p.ShowStatusBar || !p.isViewing()
+
+	if hasStatusBar {
 		return height - 1
 	}
+
 	return height
 }
 
-// How many cells are needed for this line number?
+// How many cells are needed for this line number? Includes padding.
 //
 // Returns 0 if line numbers are disabled.
 func (p *Pager) getLineNumberPrefixLength(lineNumber linemetadata.Number) int {
-	if !p.ShowLineNumbers {
+	if !p.showLineNumbers {
 		return 0
 	}
 
@@ -321,13 +332,13 @@ func (p *Pager) Quit() {
 
 // Negative deltas move left instead
 func (p *Pager) moveRight(delta int) {
-	if p.ShowLineNumbers && delta > 0 {
-		p.ShowLineNumbers = false
+	if p.showLineNumbers && delta > 0 {
+		p.showLineNumbers = false
 		return
 	}
 
 	if p.leftColumnZeroBased == 0 && delta < 0 {
-		p.ShowLineNumbers = true
+		p.showLineNumbers = true
 		return
 	}
 
@@ -408,6 +419,8 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 		}
 	}()
 
+	p.showLineNumbers = p.ShowLineNumbers
+
 	textstyles.UnprintableStyle = p.UnprintableStyle
 	if p.TabSize > 0 {
 		// "0" = unset, stay at the default. If the tab size is negative, just
@@ -432,6 +445,7 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 		spinnerFrames := [...]string{"/.\\", "-o-", "\\O/", "| |"}
 		spinnerIndex := 0
 		spinnerTicker := time.NewTicker(200 * time.Millisecond)
+		lastSpinnerFrame := "UNSET" // Track the last spinner frame to avoid unnecessary redraws
 
 		// Support throttling of more-lines-available reads, see below
 		p.readerLock.Lock()
@@ -459,6 +473,9 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 				throttledMoreLines = r.MoreLinesAdded
 				reenable = nil
 
+				// Reset spinner for new reader so that we show it again if needed
+				lastSpinnerFrame = "UNSET"
+
 				// Tell the viewer to replace the view
 				screen.Events() <- eventMoreLinesAvailable{}
 
@@ -476,15 +493,24 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 				reenable = nil
 
 			case <-spinnerTicker.C:
-				currentFrame := spinnerFrames[spinnerIndex]
+				currentSpinnerFrame := spinnerFrames[spinnerIndex]
 				if r.Done.Load() {
-					currentFrame = ""
+					// We're done, clear the spinner
+					currentSpinnerFrame = ""
 				}
+
 				spinnerIndex++
 				if spinnerIndex >= len(spinnerFrames) {
 					spinnerIndex = 0
 				}
-				screen.Events() <- eventSpinnerUpdate{currentFrame}
+
+				if currentSpinnerFrame == lastSpinnerFrame {
+					// Prevent unnecessary redraws
+					continue
+				}
+
+				screen.Events() <- eventSpinnerUpdate{currentSpinnerFrame}
+				lastSpinnerFrame = currentSpinnerFrame
 
 			case <-r.MaybeDone:
 				screen.Events() <- eventMaybeDone{}
@@ -514,11 +540,10 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 			// Also, we only do this if we have exactly one reader, because
 			// that's what less does.
 			if len(p.readers) == 1 && p.QuitIfOneScreen && !p.isShowingHelp && r.Done.Load() && r.HighlightingDone.Load() {
-				width, height := p.screen.Size()
-				if fitsOnOneScreen(r, width, height-p.DeInitFalseMargin) {
+				if p.fitsOnOneScreen() {
 					// Ref:
 					// https://github.com/walles/moor/issues/113#issuecomment-1368294132
-					p.ShowLineNumbers = false // Requires a redraw to take effect, see below
+					p.showLineNumbers = false // Requires a redraw to take effect, see below
 					p.DeInit = false
 					p.quit = true
 
@@ -597,7 +622,65 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 // shell prompt.
 //
 // This way nothing gets scrolled off screen after we exit.
-func fitsOnOneScreen(reader *reader.ReaderImpl, width int, height int) bool {
+func (p *Pager) fitsOnOneScreenWrapped() bool {
+	if len(p.readers) != 1 {
+		// At most one screen will fit on one screen...
+		return false
+	}
+
+	// Create a fake screen of height + 1 lines
+	width, height := p.screen.Size()
+
+	// If the screen height is one, and the prompt height is zero, then the last
+	// line number will be zero. But since we want one extra line to check for
+	// overflow, we now want the last line number to be one.
+	//
+	// So if the initial height is 1, we want the last line number to be 1.
+	// Which is what we get from here.
+	lastScreenRow := height - p.DeInitFalseMargin
+
+	// If the last screen row is supposed to be one, we need to set the height
+	// to two. So we add one here.
+	testScreenHeight := lastScreenRow + 1
+	testScreen := twin.NewFakeScreen(width, testScreenHeight)
+
+	// Create a fake pager for that screen, with no status bar, and matching
+	// line number settings + tab size and wrap settings
+	p.readerLock.Lock()
+	fakePager := NewPager(p.readers[0])
+	p.readerLock.Unlock()
+	fakePager.screen = testScreen
+
+	// If we drop out because of quit-if-one-screen, we will not print any line numbers
+	fakePager.showLineNumbers = false
+
+	fakePager.WrapLongLines = p.WrapLongLines
+	fakePager.ShowStatusBar = false // We are only interested in content lines
+	fakePager.TabSize = p.TabSize
+
+	// Render on our test screen
+	rendered := fakePager.renderLines()
+
+	return len(rendered.lines) < testScreenHeight
+}
+
+func (p *Pager) fitsOnOneScreen() bool {
+	if len(p.readers) != 1 {
+		// At most one screen will fit on one screen...
+		return false
+	}
+
+	if p.WrapLongLines {
+		return p.fitsOnOneScreenWrapped()
+	}
+
+	width, height := p.screen.Size()
+	height -= p.DeInitFalseMargin
+
+	p.readerLock.Lock()
+	reader := p.readers[0]
+	p.readerLock.Unlock()
+
 	if reader.GetLineCount() > height {
 		return false
 	}
@@ -616,10 +699,10 @@ func fitsOnOneScreen(reader *reader.ReaderImpl, width int, height int) bool {
 // After the pager has exited and the normal screen has been restored, you can
 // call this method to print the pager contents to screen again, faking
 // "leaving" pager contents on screen after exit.
-func (p *Pager) ReprintAfterExit() error {
+func (p *Pager) ReprintAfterExit() {
 	// Figure out how many screen lines are used by pager contents
-	renderedScreenLines, _ := p.renderScreenLines()
-	screenLinesCount := len(renderedScreenLines)
+	renderedScreen := p.renderLines()
+	screenLinesCount := len(renderedScreen.lines)
 
 	_, screenHeight := p.screen.Size()
 	screenHeightWithoutFooter := screenHeight - p.DeInitFalseMargin
@@ -631,6 +714,4 @@ func (p *Pager) ReprintAfterExit() error {
 		p.screen.ShowNLines(screenLinesCount)
 		fmt.Println()
 	}
-
-	return nil
 }
